function [deltaV,lambda,epsilon]=nma_rocket_solveRocketEquationOneStage_form3(mL,mp,ms,Isp)
%Solves rocket equation for delta V, mass of properellent and mass of structure and payload

%function [deltaV,lambda,epsilon]=nma_rocket_solveRocketEquationOneStage_form3(mL,mp,ms,Isp)
% Solves the rocket equation for delta V given Mp (mass of properellent) 
% and Ms (mass of structure) and mL (payload) and Isp  
%
% Input: 
%   mL: the mass of the payload to carry. in kg.
%   mp: mass of properllent in kg
%   ms: mass of structure in kg
%   Isp: the specific impulse. in seconds.
%
% Output:
%   deltaV: the speed gain in meters/seconds possible with this rocket.
%   lambda: the payload ratio= mL/(ms+mp)
%   epsilon: The structral mass ratio ( defined as ms/(mp+ms) ).
%
% Author: Nasser Abbasi
% May 30, 2003

g    =  9.8066;   % conversion factor
m0   =  ms+mp+mL;
mf   =  ms+mL;
deltaV  = g*Isp*log(m0/mf);
lambda  = mL/(mp+ms);
epsilon = ms/(ms+mp);